#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-utilities
version:              0.2.5.2
visibility:           public
id:                   th-utilities-0.2.5.2-FOro8HOb6VBJyz4FVnneX3
key:                  th-utilities-0.2.5.2-FOro8HOb6VBJyz4FVnneX3
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/fpco/th-utilities#readme
synopsis:
    Collection of useful functions for use with Template Haskell

category:             Template Haskell
abi:                  530370f628db3896f715ea3da7bd8697
exposed:              True
exposed-modules:
    TH.Derive TH.Derive.Storable TH.FixQ TH.ReifySimple
    TH.RelativePaths TH.Utilities

hidden-modules:       TH.Derive.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/th-utilities-0.2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-utilities
hs-libraries:         HSth-utilities-0.2.5.2-FOro8HOb6VBJyz4FVnneX3
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.8.5 filepath-1.4.300.1
    primitive-0.9.1.0-G6koubL8eviAMsrrurXf06
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE template-haskell-2.20.0.0
    text-2.0.2 th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3
    th-orphans-0.13.17-9r0J1YfjWYRGGoypw9dvTz

haddock-interfaces:
    /usr/share/doc/haskell-th-utilities/html/th-utilities.haddock

haddock-html:         /usr/share/doc/haskell-th-utilities/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

